@@ -1,9 +1,8 @@
 package MooX::Options;
 
-use strict;
-use warnings FATAL => 'all';
+use strictures 2;
 
-our $VERSION = "4.100";
+our $VERSION = "4.101";
 
 use Carp ('croak');
 use Module::Runtime qw(use_module);
@@ -48,7 +47,7 @@ sub import {
     if (@target_isa) {    #only in the main class, not a role
 
         ## no critic (ProhibitStringyEval, ErrorHandling::RequireCheckingReturnValueOfEval, ValuesAndExpressions::ProhibitImplicitNewlines)
-        eval '{
+        eval "#line ${\(__LINE__+1 . ' ' . __FILE__)}\n" . '{
         package ' . $target . ';
         use MRO::Compat ();
 
