@@ -1,7 +1,6 @@
 package MooX::Options::Descriptive::Usage;
 
-use strict;
-use warnings FATAL => 'all';
+use strictures 2;
 
 =head1 NAME
 
@@ -17,7 +16,7 @@ This class use the full size of your terminal
 
 ## no critic (ProhibitExcessComplexity)
 
-our $VERSION = "4.100";
+our $VERSION = "4.101";
 
 use Getopt::Long::Descriptive;
 use Module::Runtime qw(use_module);
