@@ -1,11 +1,10 @@
 package MooX::Options::Role;
 
-use strict;
-use warnings FATAL => 'all';
+use strictures 2;
 
 ## no critic (ProhibitExcessComplexity)
 
-our $VERSION = "4.100";
+our $VERSION = "4.101";
 
 =head1 NAME
 
